@@ -32,6 +32,8 @@ pub enum Platform {
     LinuxRiscv32,
     LinuxRiscv64,
 
+    FreeBsd64,
+
     Osx64,
     OsxArm64,
 
@@ -139,6 +141,14 @@ impl Platform {
             )))]
             compile_error!("unsupported linux architecture");
         }
+        #[cfg(target_os = "freebsd")]
+        {
+            #[cfg(target_arch = "x86_64")]
+            return Platform::FreeBsd64;
+
+            #[cfg(not(target_arch = "x86_64"))]
+            compile_error!("unsupported freebsd architecture");
+        }
         #[cfg(windows)]
         {
             #[cfg(target_arch = "x86")]
@@ -203,7 +213,9 @@ impl Platform {
 
     /// Returns true if the platform is a unix based platform.
     pub const fn is_unix(self) -> bool {
-        self.is_linux() || self.is_osx() || matches!(self, Platform::EmscriptenWasm32)
+        self.is_linux()
+            || self.is_osx()
+            || matches!(self, Platform::EmscriptenWasm32 | Platform::FreeBsd64)
     }
 
     /// Returns true if the platform is a linux based platform.
@@ -246,6 +258,7 @@ impl Platform {
             | Platform::LinuxS390X
             | Platform::LinuxRiscv32
             | Platform::LinuxRiscv64 => Some("linux"),
+            Platform::FreeBsd64 => Some("freebsd"),
             Platform::Osx64 | Platform::OsxArm64 => Some("osx"),
             Platform::Win32 | Platform::Win64 | Platform::WinArm64 => Some("win"),
             Platform::EmscriptenWasm32 => Some("emscripten"),
@@ -291,6 +304,7 @@ impl FromStr for Platform {
             "linux-s390x" => Platform::LinuxS390X,
             "linux-riscv32" => Platform::LinuxRiscv32,
             "linux-riscv64" => Platform::LinuxRiscv64,
+            "freebsd-64" => Platform::FreeBsd64,
             "osx-64" => Platform::Osx64,
             "osx-arm64" => Platform::OsxArm64,
             "win-32" => Platform::Win32,
@@ -324,6 +338,7 @@ impl From<Platform> for &'static str {
             Platform::LinuxS390X => "linux-s390x",
             Platform::LinuxRiscv32 => "linux-riscv32",
             Platform::LinuxRiscv64 => "linux-riscv64",
+            Platform::FreeBsd64 => "freebsd-64",
             Platform::Osx64 => "osx-64",
             Platform::OsxArm64 => "osx-arm64",
             Platform::Win32 => "win-32",
@@ -355,7 +370,9 @@ impl Platform {
             Platform::LinuxRiscv32 => Some(Arch::Riscv32),
             Platform::LinuxRiscv64 => Some(Arch::Riscv64),
             Platform::Linux32 | Platform::Win32 => Some(Arch::X86),
-            Platform::Linux64 | Platform::Win64 | Platform::Osx64 => Some(Arch::X86_64),
+            Platform::Linux64 | Platform::Win64 | Platform::Osx64 | Platform::FreeBsd64 => {
+                Some(Arch::X86_64)
+            }
             Platform::LinuxAarch64 => Some(Arch::Aarch64),
             Platform::WinArm64 | Platform::OsxArm64 => Some(Arch::Arm64),
             Platform::EmscriptenWasm32 | Platform::WasiWasm32 => Some(Arch::Wasm32),
@@ -504,6 +521,10 @@ mod tests {
             "linux-armv6l".parse::<Platform>().unwrap(),
             Platform::LinuxArmV6l
         );
+        assert_eq!(
+            "freebsd-64".parse::<Platform>().unwrap(),
+            Platform::FreeBsd64
+        );
         assert_eq!("win-arm64".parse::<Platform>().unwrap(), Platform::WinArm64);
         assert_eq!(
             "emscripten-wasm32".parse::<Platform>().unwrap(),
@@ -545,6 +566,7 @@ mod tests {
         assert_eq!(Platform::LinuxS390X.arch(), Some(Arch::S390X));
         assert_eq!(Platform::LinuxRiscv32.arch(), Some(Arch::Riscv32));
         assert_eq!(Platform::LinuxRiscv64.arch(), Some(Arch::Riscv64));
+        assert_eq!(Platform::FreeBsd64.arch(), Some(Arch::X86_64));
         assert_eq!(Platform::Osx64.arch(), Some(Arch::X86_64));
         assert_eq!(Platform::OsxArm64.arch(), Some(Arch::Arm64));
         assert_eq!(Platform::Win32.arch(), Some(Arch::X86));
