@@ -15,15 +15,15 @@ use crate::no_std_compat::*;
 use crate::private;
 
 /// Interface to provide meaning to a byte slice such that paths can be derived
-pub trait Utf8Encoding<'a>: private::Sealed {
+pub trait Utf8Encoding: private::Sealed {
     /// Represents the type of component that will be derived by this encoding
-    type Components: Utf8Components<'a>;
+    type Components<'a>: Utf8Components<'a>;
 
     /// Static label representing encoding type
     fn label() -> &'static str;
 
     /// Produces an iterator of [`Utf8Component`]s over the given the byte slice (`path`)
-    fn components(path: &'a str) -> Self::Components;
+    fn components(path: &str) -> Self::Components<'_>;
 
     /// Hashes a utf8 str (`path`)
     fn hash<H: Hasher>(path: &str, h: &mut H);
