@@ -3,7 +3,7 @@ pub unsafe fn IsDestinationReachableA<P0>(lpszdestination: P0, lpqocinfo: *mut Q
 where
     P0: windows_core::Param<windows_core::PCSTR>,
 {
-    windows_core::link!("sensapi.dll" "system" fn IsDestinationReachableA(lpszdestination : windows_core::PCSTR, lpqocinfo : *mut QOCINFO) -> windows_core::BOOL);
+    windows_targets::link!("sensapi.dll" "system" fn IsDestinationReachableA(lpszdestination : windows_core::PCSTR, lpqocinfo : *mut QOCINFO) -> super::super::Foundation:: BOOL);
     unsafe { IsDestinationReachableA(lpszdestination.param().abi(), lpqocinfo as _).ok() }
 }
 #[inline]
@@ -11,12 +11,12 @@ pub unsafe fn IsDestinationReachableW<P0>(lpszdestination: P0, lpqocinfo: *mut Q
 where
     P0: windows_core::Param<windows_core::PCWSTR>,
 {
-    windows_core::link!("sensapi.dll" "system" fn IsDestinationReachableW(lpszdestination : windows_core::PCWSTR, lpqocinfo : *mut QOCINFO) -> windows_core::BOOL);
+    windows_targets::link!("sensapi.dll" "system" fn IsDestinationReachableW(lpszdestination : windows_core::PCWSTR, lpqocinfo : *mut QOCINFO) -> super::super::Foundation:: BOOL);
     unsafe { IsDestinationReachableW(lpszdestination.param().abi(), lpqocinfo as _).ok() }
 }
 #[inline]
 pub unsafe fn IsNetworkAlive(lpdwflags: *mut u32) -> windows_core::Result<()> {
-    windows_core::link!("sensapi.dll" "system" fn IsNetworkAlive(lpdwflags : *mut u32) -> windows_core::BOOL);
+    windows_targets::link!("sensapi.dll" "system" fn IsNetworkAlive(lpdwflags : *mut u32) -> super::super::Foundation:: BOOL);
     unsafe { IsNetworkAlive(lpdwflags as _).ok() }
 }
 pub const CONNECTION_AOL: u32 = 4u32;
@@ -59,7 +59,6 @@ impl ISensLogon {
 }
 #[cfg(feature = "Win32_System_Com")]
 #[repr(C)]
-#[doc(hidden)]
 pub struct ISensLogon_Vtbl {
     pub base__: super::Com::IDispatch_Vtbl,
     pub Logon: unsafe extern "system" fn(*mut core::ffi::c_void, *mut core::ffi::c_void) -> windows_core::HRESULT,
@@ -173,7 +172,6 @@ impl ISensLogon2 {
 }
 #[cfg(feature = "Win32_System_Com")]
 #[repr(C)]
-#[doc(hidden)]
 pub struct ISensLogon2_Vtbl {
     pub base__: super::Com::IDispatch_Vtbl,
     pub Logon: unsafe extern "system" fn(*mut core::ffi::c_void, *mut core::ffi::c_void, u32) -> windows_core::HRESULT,
@@ -269,7 +267,6 @@ impl ISensNetwork {
 }
 #[cfg(feature = "Win32_System_Com")]
 #[repr(C)]
-#[doc(hidden)]
 pub struct ISensNetwork_Vtbl {
     pub base__: super::Com::IDispatch_Vtbl,
     pub ConnectionMade: unsafe extern "system" fn(*mut core::ffi::c_void, *mut core::ffi::c_void, u32, *const SENS_QOCINFO) -> windows_core::HRESULT,
@@ -359,7 +356,6 @@ impl ISensOnNow {
 }
 #[cfg(feature = "Win32_System_Com")]
 #[repr(C)]
-#[doc(hidden)]
 pub struct ISensOnNow_Vtbl {
     pub base__: super::Com::IDispatch_Vtbl,
     pub OnACPower: unsafe extern "system" fn(*mut core::ffi::c_void) -> windows_core::HRESULT,
@@ -411,13 +407,18 @@ pub const NETWORK_ALIVE_INTERNET: u32 = 8u32;
 pub const NETWORK_ALIVE_LAN: u32 = 1u32;
 pub const NETWORK_ALIVE_WAN: u32 = 2u32;
 #[repr(C)]
-#[derive(Clone, Copy, Debug, Default, PartialEq)]
+#[derive(Clone, Copy, Debug, PartialEq)]
 pub struct QOCINFO {
     pub dwSize: u32,
     pub dwFlags: u32,
     pub dwInSpeed: u32,
     pub dwOutSpeed: u32,
 }
+impl Default for QOCINFO {
+    fn default() -> Self {
+        unsafe { core::mem::zeroed() }
+    }
+}
 pub const SENS: windows_core::GUID = windows_core::GUID::from_u128(0xd597cafe_5b9f_11d1_8dd2_00aa004abd5e);
 pub const SENSGUID_EVENTCLASS_LOGON: windows_core::GUID = windows_core::GUID::from_u128(0xd5978630_5b9f_11d1_8dd2_00aa004abd5e);
 pub const SENSGUID_EVENTCLASS_LOGON2: windows_core::GUID = windows_core::GUID::from_u128(0xd5978650_5b9f_11d1_8dd2_00aa004abd5e);
@@ -430,10 +431,15 @@ pub const SENSGUID_SUBSCRIBER_WININET: windows_core::GUID = windows_core::GUID::
 #[derive(Clone, Copy, Debug, Default, Eq, PartialEq)]
 pub struct SENS_CONNECTION_TYPE(pub u32);
 #[repr(C)]
-#[derive(Clone, Copy, Debug, Default, PartialEq)]
+#[derive(Clone, Copy, Debug, PartialEq)]
 pub struct SENS_QOCINFO {
     pub dwSize: u32,
     pub dwFlags: u32,
     pub dwOutSpeed: u32,
     pub dwInSpeed: u32,
 }
+impl Default for SENS_QOCINFO {
+    fn default() -> Self {
+        unsafe { core::mem::zeroed() }
+    }
+}
